@@ -78,7 +78,7 @@ use Sys::Virt::NWFilter;
 use Sys::Virt::DomainSnapshot;
 use Sys::Virt::Stream;
 
-our $VERSION = '1.2.8';
+our $VERSION = '1.2.13';
 require XSLoader;
 XSLoader::load('Sys::Virt', $VERSION);
 
@@ -262,7 +262,7 @@ sub create_domain_with_files {
 				   fds => $fds, flags => $flags);
 }
 
-=item my $dom = $vmm->define_domain($xml);
+=item my $dom = $vmm->define_domain($xml, $flags=0);
 
 Defines, but does not start, a new domain based on the XML description
 passed into the C<$xml> parameter. The returned object is an instance
@@ -276,8 +276,9 @@ object.
 sub define_domain {
     my $self = shift;
     my $xml = shift;
+    my $flags = shift || 0;
 
-    return Sys::Virt::Domain->_new(connection => $self, xml => $xml, nocreate => 1);
+    return Sys::Virt::Domain->_new(connection => $self, xml => $xml, nocreate => 1, flags => $flags);
 }
 
 =item my $dom = $vmm->create_network($xml);
@@ -1674,6 +1675,30 @@ free page information for that cell. The 'pages' value is another
 hash reference where the keys are the page sizes and the values
 are the free count for that size.
 
+=item $con->node_alloc_pages(\@pages, $start, $end, $flags=0)
+
+Allocate further huge pages for the reserved pool. The <\@pages>
+parameter is an array reference with one entry per page size to
+allocate for. Each entry is a further array reference where the
+first element is the page size and the second element is the
+page count. The same number of pages will be allocated on each
+NUMA node in the range C<$start> to C<$end> inclusive. The
+C<$flags> parameter accepts two contants
+
+=over 4
+
+=item Sys::Virt::NODE_ALLOC_PAGES_ADD
+
+The requested number of pages will be added to the existing huge
+page reservation.
+
+=item Sys::Virt::NODE_ALLOC_PAGES_SET
+
+The huge page reservation will be set to exactly the requested
+number
+
+=back
+
 =back
 
 =head1 CONSTANTS
@@ -1834,6 +1859,10 @@ How many pages changing too fast to be placed in a tree.
 
 How many milliseconds the shared memory service should sleep before next scan.
 
+=item Sys::Virt::NODE_MEMORY_SHARED_MERGE_ACROSS_NODES
+
+Whether pages can be merged across NUMA nodes
+
 =back
 
 =head2 CLOSE REASON CONSTANTS
